"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const path = require('path');
/*::

type ApiType = {|
  +assertVersion: number => void,
|}

type ExternalOptions = {|
  +target: 'js' | 'flow',
|}

type BabelRule = string | [string, Object];
type BabelRules = $ReadOnlyArray<BabelRule>;

*/


module.exports = (api
/*: ApiType */
, externalOptions
/*: ExternalOptions */
) => {
  api.assertVersion(7);

  const options = _objectSpread({
    target: 'js'
  }, externalOptions);

  if (options.target !== 'js' && options.target !== 'flow') {
    throw new Error('options.target must be one of "js" or "flow".');
  }

  let presets
  /*: BabelRules */
  = [];
  let plugins
  /*: BabelRules */
  = ['@babel/plugin-proposal-class-properties', '@babel/plugin-proposal-nullish-coalescing-operator', '@babel/plugin-proposal-optional-chaining', '@babel/plugin-syntax-flow', // allow parsing of the flow syntax (overlaps with flow-strip-types for JS)
  '@babel/plugin-syntax-jsx'];

  if (options.target === 'flow') {
    plugins = plugins.concat([path.join(__dirname, 'dev-declaration')]);
  }

  if (options.target === 'js') {
    presets = presets.concat([['@babel/preset-env', {
      modules: 'commonjs',
      targets: {
        node: 'current'
      }
    }], '@babel/preset-react']);
    plugins = plugins.concat([path.join(__dirname, 'dev-expression.js'), '@babel/plugin-proposal-object-rest-spread', '@babel/plugin-transform-flow-strip-types', 'babel-plugin-relay']);
  }

  return {
    presets,
    plugins
  };
};